pub struct BatchingModeOptions {
pub query_timeout: Duration,
pub slow_query_threshold: Duration,
pub experimental_min_refresh_duration: Duration,
pub grpc_conn_timeout: Duration,
pub experimental_grpc_max_retries: u32,
pub experimental_frontend_scan_timeout: Duration,
pub experimental_max_filter_num_per_query: usize,
pub experimental_time_window_merge_threshold: usize,
pub read_preference: ReadPreference,
pub frontend_tls: Option<ClientTlsOption>,
}Fields
query_timeout: DurationThe default batching engine query timeout is 10 minutes
slow_query_threshold: Durationwill output a warn log for any query that runs for more that this threshold
experimental_min_refresh_duration: DurationThe minimum duration between two queries execution by batching mode task
grpc_conn_timeout: DurationThe gRPC connection timeout
experimental_grpc_max_retries: u32The gRPC max retry number
experimental_frontend_scan_timeout: DurationFlow wait for available frontend timeout, if failed to find available frontend after frontend_scan_timeout elapsed, return error which prevent flownode from starting
experimental_max_filter_num_per_query: usizeMaximum number of filters allowed in a single query
experimental_time_window_merge_threshold: usizeTime window merge distance
read_preference: ReadPreferenceRead preference of the Frontend client.
frontend_tls: Option<ClientTlsOption>TLS option for client connections to frontends.